==> alist-3.17.0.tar.gz: alist-3.17.0/drivers/all.go <==
package drivers

import (
	_ "github.com/alist-org/alist/v3/drivers/115"
	_ "github.com/alist-org/alist/v3/drivers/123"
	_ "github.com/alist-org/alist/v3/drivers/139"
	_ "github.com/alist-org/alist/v3/drivers/189"
	_ "github.com/alist-org/alist/v3/drivers/189pc"
	_ "github.com/alist-org/alist/v3/drivers/alias"
	_ "github.com/alist-org/alist/v3/drivers/alist_v2"
	_ "github.com/alist-org/alist/v3/drivers/alist_v3"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive_open"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive_share"
	_ "github.com/alist-org/alist/v3/drivers/baidu_netdisk"
	_ "github.com/alist-org/alist/v3/drivers/baidu_photo"
	_ "github.com/alist-org/alist/v3/drivers/baidu_share"
	_ "github.com/alist-org/alist/v3/drivers/cloudreve"
	_ "github.com/alist-org/alist/v3/drivers/ftp"
	_ "github.com/alist-org/alist/v3/drivers/google_drive"
	_ "github.com/alist-org/alist/v3/drivers/google_photo"
	_ "github.com/alist-org/alist/v3/drivers/ipfs_api"
	_ "github.com/alist-org/alist/v3/drivers/lanzou"
	_ "github.com/alist-org/alist/v3/drivers/local"
	_ "github.com/alist-org/alist/v3/drivers/mediatrack"
	_ "github.com/alist-org/alist/v3/drivers/mega"
	_ "github.com/alist-org/alist/v3/drivers/onedrive"
	_ "github.com/alist-org/alist/v3/drivers/onedrive_app"
	_ "github.com/alist-org/alist/v3/drivers/pikpak"
	_ "github.com/alist-org/alist/v3/drivers/pikpak_share"
	_ "github.com/alist-org/alist/v3/drivers/quark"
	_ "github.com/alist-org/alist/v3/drivers/s3"
	_ "github.com/alist-org/alist/v3/drivers/seafile"
	_ "github.com/alist-org/alist/v3/drivers/sftp"
	_ "github.com/alist-org/alist/v3/drivers/smb"
	_ "github.com/alist-org/alist/v3/drivers/teambition"
	_ "github.com/alist-org/alist/v3/drivers/terabox"
	_ "github.com/alist-org/alist/v3/drivers/thunder"
	_ "github.com/alist-org/alist/v3/drivers/trainbit"
	_ "github.com/alist-org/alist/v3/drivers/url_tree"
	_ "github.com/alist-org/alist/v3/drivers/uss"
	_ "github.com/alist-org/alist/v3/drivers/virtual"
	_ "github.com/alist-org/alist/v3/drivers/webdav"
	_ "github.com/alist-org/alist/v3/drivers/yandex_disk"
)

// All do nothing,just for import
// same as _ import
func All() {

}

==> alist-3.18.0.tar.gz: alist-3.18.0/drivers/all.go <==
package drivers

import (
	_ "github.com/alist-org/alist/v3/drivers/115"
	_ "github.com/alist-org/alist/v3/drivers/123"
	_ "github.com/alist-org/alist/v3/drivers/139"
	_ "github.com/alist-org/alist/v3/drivers/189"
	_ "github.com/alist-org/alist/v3/drivers/189pc"
	_ "github.com/alist-org/alist/v3/drivers/alias"
	_ "github.com/alist-org/alist/v3/drivers/alist_v2"
	_ "github.com/alist-org/alist/v3/drivers/alist_v3"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive_open"
	_ "github.com/alist-org/alist/v3/drivers/aliyundrive_share"
	_ "github.com/alist-org/alist/v3/drivers/baidu_netdisk"
	_ "github.com/alist-org/alist/v3/drivers/baidu_photo"
	_ "github.com/alist-org/alist/v3/drivers/baidu_share"
	_ "github.com/alist-org/alist/v3/drivers/cloudreve"
	_ "github.com/alist-org/alist/v3/drivers/ftp"
	_ "github.com/alist-org/alist/v3/drivers/google_drive"
	_ "github.com/alist-org/alist/v3/drivers/google_photo"
	_ "github.com/alist-org/alist/v3/drivers/ipfs_api"
	_ "github.com/alist-org/alist/v3/drivers/lanzou"
	_ "github.com/alist-org/alist/v3/drivers/local"
	_ "github.com/alist-org/alist/v3/drivers/mediatrack"
	_ "github.com/alist-org/alist/v3/drivers/mega"
	_ "github.com/alist-org/alist/v3/drivers/onedrive"
	_ "github.com/alist-org/alist/v3/drivers/onedrive_app"
	_ "github.com/alist-org/alist/v3/drivers/pikpak"
	_ "github.com/alist-org/alist/v3/drivers/pikpak_share"
	_ "github.com/alist-org/alist/v3/drivers/quark_uc"
	_ "github.com/alist-org/alist/v3/drivers/s3"
	_ "github.com/alist-org/alist/v3/drivers/seafile"
	_ "github.com/alist-org/alist/v3/drivers/sftp"
	_ "github.com/alist-org/alist/v3/drivers/smb"
	_ "github.com/alist-org/alist/v3/drivers/teambition"
	_ "github.com/alist-org/alist/v3/drivers/terabox"
	_ "github.com/alist-org/alist/v3/drivers/thunder"
	_ "github.com/alist-org/alist/v3/drivers/trainbit"
	_ "github.com/alist-org/alist/v3/drivers/url_tree"
	_ "github.com/alist-org/alist/v3/drivers/uss"
	_ "github.com/alist-org/alist/v3/drivers/virtual"
	_ "github.com/alist-org/alist/v3/drivers/webdav"
	_ "github.com/alist-org/alist/v3/drivers/yandex_disk"
)

// All do nothing,just for import
// same as _ import
func All() {

}
